==> python-dateparser-1.0.0-2-any.pkg.tar.xz: usr/lib/python3.9/site-packages/dateparser/data/date_translation_data/sl.py <==
info = {
    "name": "sl",
    "date_order": "DMY",
    "january": [
        "januar",
        "jan"
    ],
    "february": [
        "februar",
        "feb"
    ],
    "march": [
        "marec",
        "mar"
    ],
    "april": [
        "april",
        "apr"
    ],
    "may": [
        "maj"
    ],
    "june": [
        "junij",
        "jun"
    ],
    "july": [
        "julij",
        "jul"
    ],
    "august": [
        "avgust",
        "avg"
    ],
    "september": [
        "september",
        "sep"
    ],
    "october": [
        "oktober",
        "okt"
    ],
    "november": [
        "november",
        "nov"
    ],
    "december": [
        "december",
        "dec"
    ],
    "monday": [
        "ponedeljek",
        "pon"
    ],
    "tuesday": [
        "torek",
        "tor"
    ],
    "wednesday": [
        "sreda",
        "sre"
    ],
    "thursday": [
        "četrtek",
        "čet"
    ],
    "friday": [
        "petek",
        "pet"
    ],
    "saturday": [
        "sobota",
        "sob"
    ],
    "sunday": [
        "nedelja",
        "ned"
    ],
    "am": [
        "dopoldne",
        "dop"
    ],
    "pm": [
        "popoldne",
        "pop"
    ],
    "year": [
        "leto"
    ],
    "month": [
        "mesec",
        "mes"
    ],
    "week": [
        "teden",
        "ted"
    ],
    "day": [
        "dan"
    ],
    "hour": [
        "ura",
        "h"
    ],
    "minute": [
        "minuta",
        "min"
    ],
    "second": [
        "sekunda",
        "sek",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "lani"
        ],
        "0 year ago": [
            "letos"
        ],
        "in 1 year": [
            "naslednje leto"
        ],
        "1 month ago": [
            "prejšnji mesec"
        ],
        "0 month ago": [
            "ta mesec"
        ],
        "in 1 month": [
            "naslednji mesec"
        ],
        "1 week ago": [
            "prejšnji teden"
        ],
        "0 week ago": [
            "ta teden"
        ],
        "in 1 week": [
            "naslednji teden"
        ],
        "1 day ago": [
            "včeraj"
        ],
        "0 day ago": [
            "danes"
        ],
        "in 1 day": [
            "jutri"
        ],
        "0 hour ago": [
            "v tej uri"
        ],
        "0 minute ago": [
            "to minuto"
        ],
        "0 second ago": [
            "zdaj"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "čez (\\d+) leto",
            "čez (\\d+) let"
        ],
        "\\1 year ago": [
            "pred (\\d+) letom",
            "pred (\\d+) leti"
        ],
        "in \\1 month": [
            "čez (\\d+) mesec",
            "čez (\\d+) mesecev",
            "čez (\\d+) mes"
        ],
        "\\1 month ago": [
            "pred (\\d+) mesecem",
            "pred (\\d+) meseci",
            "pred (\\d+) mes"
        ],
        "in \\1 week": [
            "čez (\\d+) teden",
            "čez (\\d+) tednov",
            "čez (\\d+) ted"
        ],
        "\\1 week ago": [
            "pred (\\d+) tednom",
            "pred (\\d+) tedni",
            "pred (\\d+) ted"
        ],
        "in \\1 day": [
            "čez (\\d+) dan",
            "čez (\\d+) dni"
        ],
        "\\1 day ago": [
            "pred (\\d+) dnevom",
            "pred (\\d+) dnevi"
        ],
        "in \\1 hour": [
            "čez (\\d+) uro",
            "čez (\\d+) ur",
            "čez (\\d+) h"
        ],
        "\\1 hour ago": [
            "pred (\\d+) uro",
            "pred (\\d+) urami",
            "pred (\\d+) h"
        ],
        "in \\1 minute": [
            "čez (\\d+) minuto",
            "čez (\\d+) minut",
            "čez (\\d+) min"
        ],
        "\\1 minute ago": [
            "pred (\\d+) minuto",
            "pred (\\d+) minutami",
            "pred (\\d+) min"
        ],
        "in \\1 second": [
            "čez (\\d+) sekundo",
            "čez (\\d+) sekund",
            "čez (\\d+) s"
        ],
        "\\1 second ago": [
            "pred (\\d+) sekundo",
            "pred (\\d+) sekundami",
            "pred (\\d+) s"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}

==> python-dateparser-1.1.0-1-any.pkg.tar.xz: usr/lib/python3.9/site-packages/dateparser/data/date_translation_data/sl.py <==
info = {
    "name": "sl",
    "date_order": "DMY",
    "january": [
        "jan",
        "januar"
    ],
    "february": [
        "feb",
        "februar"
    ],
    "march": [
        "mar",
        "marec"
    ],
    "april": [
        "apr",
        "april"
    ],
    "may": [
        "maj"
    ],
    "june": [
        "jun",
        "junij"
    ],
    "july": [
        "jul",
        "julij"
    ],
    "august": [
        "avg",
        "avgust"
    ],
    "september": [
        "sep",
        "september"
    ],
    "october": [
        "okt",
        "oktober"
    ],
    "november": [
        "nov",
        "november"
    ],
    "december": [
        "dec",
        "december"
    ],
    "monday": [
        "pon",
        "ponedeljek"
    ],
    "tuesday": [
        "tor",
        "torek"
    ],
    "wednesday": [
        "sre",
        "sreda"
    ],
    "thursday": [
        "čet",
        "četrtek"
    ],
    "friday": [
        "pet",
        "petek"
    ],
    "saturday": [
        "sob",
        "sobota"
    ],
    "sunday": [
        "ned",
        "nedelja"
    ],
    "am": [
        "dop",
        "dopoldne"
    ],
    "pm": [
        "pop",
        "popoldne"
    ],
    "year": [
        "leto"
    ],
    "month": [
        "mes",
        "mesec"
    ],
    "week": [
        "ted",
        "teden"
    ],
    "day": [
        "dan"
    ],
    "hour": [
        "h",
        "ura"
    ],
    "minute": [
        "min",
        "minuta"
    ],
    "second": [
        "s",
        "sek",
        "sekunda"
    ],
    "relative-type": {
        "0 day ago": [
            "danes"
        ],
        "0 hour ago": [
            "v tej uri"
        ],
        "0 minute ago": [
            "to minuto"
        ],
        "0 month ago": [
            "ta mesec"
        ],
        "0 second ago": [
            "zdaj"
        ],
        "0 week ago": [
            "ta teden"
        ],
        "0 year ago": [
            "letos"
        ],
        "1 day ago": [
            "včeraj"
        ],
        "1 month ago": [
            "prejšnji mesec"
        ],
        "1 week ago": [
            "prejšnji teden"
        ],
        "1 year ago": [
            "lani"
        ],
        "in 1 day": [
            "jutri"
        ],
        "in 1 month": [
            "naslednji mesec"
        ],
        "in 1 week": [
            "naslednji teden"
        ],
        "in 1 year": [
            "naslednje leto"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "pred (\\d+) dnevi",
            "pred (\\d+) dnevom"
        ],
        "\\1 hour ago": [
            "pred (\\d+) h",
            "pred (\\d+) urami",
            "pred (\\d+) uro"
        ],
        "\\1 minute ago": [
            "pred (\\d+) min",
            "pred (\\d+) minutami",
            "pred (\\d+) minuto"
        ],
        "\\1 month ago": [
            "pred (\\d+) mes",
            "pred (\\d+) mesecem",
            "pred (\\d+) meseci"
        ],
        "\\1 second ago": [
            "pred (\\d+) s",
            "pred (\\d+) sekundami",
            "pred (\\d+) sekundo"
        ],
        "\\1 week ago": [
            "pred (\\d+) ted",
            "pred (\\d+) tedni",
            "pred (\\d+) tednom"
        ],
        "\\1 year ago": [
            "pred (\\d+) leti",
            "pred (\\d+) letom"
        ],
        "in \\1 day": [
            "čez (\\d+) dan",
            "čez (\\d+) dni"
        ],
        "in \\1 hour": [
            "čez (\\d+) h",
            "čez (\\d+) ur",
            "čez (\\d+) uro"
        ],
        "in \\1 minute": [
            "čez (\\d+) min",
            "čez (\\d+) minut",
            "čez (\\d+) minuto"
        ],
        "in \\1 month": [
            "čez (\\d+) mes",
            "čez (\\d+) mesec",
            "čez (\\d+) mesecev"
        ],
        "in \\1 second": [
            "čez (\\d+) s",
            "čez (\\d+) sekund",
            "čez (\\d+) sekundo"
        ],
        "in \\1 week": [
            "čez (\\d+) ted",
            "čez (\\d+) teden",
            "čez (\\d+) tednov"
        ],
        "in \\1 year": [
            "čez (\\d+) let",
            "čez (\\d+) leto"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
